pub fn initialize_v8(jit_mode: V8JitMode) -> Result<(), String>Expand description
Initializes the process-wide V8 platform with the requested JIT mode.
Call this before executing any code-mode cells when JIT must be disabled. V8 cannot change JIT mode after initialization, so a later call requesting a different mode returns an error. Code mode initializes V8 with JIT enabled by default when this function has not been called explicitly.